EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ApplicationGroups_GetOrCreateApplicationGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ApplicationGroup_Id',
    /* Description_Text        */ 'Gets or creates a new application group using the name'
GO

IF OBJECT_ID('[ApplicationGroups_GetOrCreateApplicationGroup]') IS NOT NULL DROP PROCEDURE [ApplicationGroups_GetOrCreateApplicationGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ApplicationGroups_GetOrCreateApplicationGroup]
(
	@ApplicationGroup_Name VARCHAR(50),
    @ApplicationGroup_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON 

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @Existing_ApplicationGroup_Id INT
    DECLARE @Existing_ApplicationGroup_Name VARCHAR(50)

    SELECT @Existing_ApplicationGroup_Name = [ApplicationGroup_Name],
           @Existing_ApplicationGroup_Id = [ApplicationGroup_Id]
      FROM [ApplicationGroups]
     WHERE [ApplicationGroup_Name] = @ApplicationGroup_Name
    
    IF (@ApplicationGroup_Name IS NULL OR LTRIM(RTRIM(@ApplicationGroup_Name)) = '')
    BEGIN
        
        SET @ApplicationGroup_Id = NULL

    END
	ELSE IF (@Existing_ApplicationGroup_Id IS NULL)
	BEGIN

		INSERT INTO [ApplicationGroups]
		(
			[ApplicationGroup_Name],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@ApplicationGroup_Name,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)
		
		SET @ApplicationGroup_Id = SCOPE_IDENTITY()

	END
    ELSE
    BEGIN

        SET @ApplicationGroup_Id = @Existing_ApplicationGroup_Id

    END
	
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ApplicationGroups_GetOrCreateApplicationGroup] TO [BuildMasterUser_Role]
