EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_DeactivateApplication',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deactivates an application, removing it from menu options but preserves data.'
GO

IF OBJECT_ID('[Applications_DeactivateApplication]') IS NOT NULL
	DROP PROCEDURE [Applications_DeactivateApplication]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_DeactivateApplication]
(
	@Application_Id INT
) 
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION


	UPDATE [Applications]
	   SET [Active_Indicator] = 'N'
	 WHERE [Application_Id] = @Application_Id

     IF @@ROWCOUNT = 0 RAISERROR('Application %i does not exist.',16,1, @Application_Id)

    UPDATE [RetentionPolicies]
       SET [Active_Indicator] = 'N'
	 WHERE [PurgeIn_Application_Id] = @Application_Id

     DECLARE @ActiveReleases TABLE 
     (
        [Release_Number] RELEASENUMBER
     )

     INSERT @ActiveReleases ([Release_Number])
     SELECT [Release_Number] 
       FROM [Releases]
      WHERE [Application_Id] = @Application_Id
        AND [ReleaseStatus_Name] = 'Active'

      DECLARE @Current_ReleaseNumber RELEASENUMBER

      WHILE EXISTS(SELECT * FROM @ActiveReleases)
      BEGIN

        SELECT TOP 1 @Current_ReleaseNumber = [Release_Number] FROM @ActiveReleases

        EXEC [Releases_CancelRelease]
                @Application_Id,
	            @Release_Number = @Current_ReleaseNumber,
	            @CancelledReason_Text = 'Application was deactivated'
        
        DELETE @ActiveReleases WHERE [Release_Number] = @Current_ReleaseNumber

      END


	/* Raise Event */
	EXEC [Events_RaiseEvent] 'APPMOD',@Application_Id


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_DeactivateApplication] TO [BuildMasterUser_Role]