EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_ImportBuild',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Build_Id',
    /* Description_Text        */ 'Imports build information.'
GO

IF OBJECT_ID('[Builds_ImportBuild]') IS NOT NULL DROP PROCEDURE [Builds_ImportBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_ImportBuild]
(
	@Release_Id INT,
	@Application_Id INT,
	@Build_Number BUILDNUMBER,
	@BuildStatus_Name VARCHAR(8),
	@Rejection_Notes VARCHAR(255),
	@CreatedBy_User_Name USERNAME,
	@CreatedOn_Date DATETIME,
	@ModifiedBy_User_Name USERNAME,
	@ModifiedOn_Date DATETIME,
	@RejectedBy_User_Name USERNAME,
	@Rejected_Date DATETIME,
	@Build_Sequence INT,
	@Furthest_PipelineStage_Name VARCHAR(50),
	@Build_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Builds]
	(
		[Release_Id],
		[Application_Id],
		[Build_Number],
		[BuildStatus_Name],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[Build_Sequence],
		[RejectedBy_User_Name],
		[Rejected_Date],
		[Rejection_Notes],
		[Furthest_PipelineStage_Name]
	)
	VALUES
	(
		@Release_Id,
		@Application_Id,
		@Build_Number,
		@BuildStatus_Name,
		@CreatedBy_User_Name,
		@CreatedOn_Date,
		@ModifiedBy_User_Name,
		@ModifiedOn_Date,
		@Build_Sequence,
		@RejectedBy_User_Name,
		@Rejected_Date,
		@Rejection_Notes,
		@Furthest_PipelineStage_Name
	)

	SET @Build_Id = SCOPE_IDENTITY()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_ImportBuild] TO [BuildMasterUser_Role]
