EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Promotions_SchedulePromotion',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Schedules a promotion or removes a previously scheduled promotion.'
GO

IF OBJECT_ID('[Promotions_SchedulePromotion]') IS NOT NULL 
	DROP PROCEDURE [Promotions_SchedulePromotion]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Promotions_SchedulePromotion]
(
	@Build_Id INT,
	@PipelineStage_Name VARCHAR(50),
	@PromoteOn_Date DATETIME,
	@Comments_Text VARCHAR(255) = NULL,
	@Variables_Xml XML = NULL
) AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [BuildPromotions_Extended]
			   WHERE [Build_Id] = @Build_Id
				 AND [PipelineStage_Name] = @PipelineStage_Name)
	BEGIN
		RAISERROR('Build has already been promoted. Cannot schedule promotion.', 16, 1)
	END

	IF @PromoteOn_Date IS NULL
	BEGIN

		DELETE [BuildPromotionsScheduled]
	     WHERE [Build_Id] = @Build_Id
		   AND [PipelineStage_Name] = @PipelineStage_Name

	END
	ELSE IF EXISTS(SELECT *
	            FROM [BuildPromotionsScheduled]
	           WHERE [Build_Id] = @Build_Id
		         AND [PipelineStage_Name] = @PipelineStage_Name)
	BEGIN

		UPDATE [BuildPromotionsScheduled]
		   SET [PromoteOn_Date] = @PromoteOn_Date,
		       [Comments_Text] = @Comments_Text,
			   [Variables_Xml] = @Variables_Xml
	     WHERE [Build_Id] = @Build_Id
		   AND [PipelineStage_Name] = @PipelineStage_Name

	END
	ELSE
	BEGIN

		INSERT INTO [BuildPromotionsScheduled]
		(
			[Build_Id],
			[PipelineStage_Name],
			[PromoteOn_Date],
			[Comments_Text],
			[Variables_Xml]
		)
		VALUES
		(
			@Build_Id,
			@PipelineStage_Name,
			@PromoteOn_Date,
			@Comments_Text,
			@Variables_Xml
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Promotions_SchedulePromotion] TO [BuildMasterUser_Role]