EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Security_GetOrAddAnonymousRole',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Role_Id',
    /* Description_Text        */ 'Gets an anonymous role containing the specified tasks, creating one if necessary.'
GO

IF OBJECT_ID('[Security_GetOrAddAnonymousRole]') IS NOT NULL
	DROP PROCEDURE [Security_GetOrAddAnonymousRole]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Security_GetOrAddAnonymousRole]
(
	@Tasks_Csv VARCHAR(MAX),
	@Role_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Tasks TABLE([Task_Id] INT NOT NULL)

	INSERT INTO @Tasks
	SELECT DISTINCT CAST([Value_Text] AS INT)
	  FROM dbo.CsvToTable(@Tasks_Csv, ',')

	DECLARE @Task_Count INT
	SET @Task_Count = (SELECT COUNT(*) FROM @Tasks)

	SET @Role_Id = (SELECT TOP 1 RT.[Role_Id]
	                  FROM @Tasks T
	                       INNER JOIN [RoleTasks] RT
		                           ON RT.[Task_Id] = T.[Task_Id]
		                   INNER JOIN [Roles] R
		                           ON R.[Role_Id] = RT.[Role_Id]
	                 WHERE R.[Role_Name] IS NULL
	                 GROUP BY RT.[Role_Id]
	                HAVING COUNT(*) = @Task_Count)

	IF @Role_Id IS NULL
	BEGIN

		INSERT INTO [Roles] ([Role_Name]) VALUES (NULL)
		SET @Role_Id = SCOPE_IDENTITY()

		INSERT INTO [RoleTasks]
		(
			[Role_Id],
			[Task_Id]
		)
		SELECT [Role_Id] = @Role_Id,
		       [Task_Id]
		  FROM @Tasks

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Security_GetOrAddAnonymousRole] TO [BuildMasterUser_Role]
GO
